import setuptools
setuptools.setup(
    name="omarlibone",
    version="1.1",
    author="omar Style",
    description="omar aAAA",
    packages=setuptools.find_packages(),
    classifiers=[
    "Programming Language :: Python :: 3 ",
    "Operating System :: OS Independent",
    "Natural Language :: English",
    "License :: OSI Approved :: MIT License"
    ]
    
)